/*
 * Copyright (C) 2008 QUIPSY QUALITY GmbH & Co. KG
 */

package entities;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Embeddable;

/**
 * 
 * @author Ralf HAMBERGER (hamberger@quipsy.de)
 */
@SuppressWarnings("serial")
@Embeddable
public class ManufacturedAmountPk implements Serializable {

    @Column(name = "partId", insertable = false, updatable = false)
    private String partId;

    @Column(name = "partVersion", insertable = false, updatable = false)
    private String partVersion;

    private short year;

    public ManufacturedAmountPk() {
        // Intentionally left blank.
    }

    public ManufacturedAmountPk(final String partId, final String partVersion, final short year) {
        this.partId = partId;
        this.partVersion = partVersion;
        this.year = year;
    }

    public ManufacturedAmountPk(final Part part, final short year) {
        this(part.getId(), part.getVersion(), year);
    }

    public final String getPartId() {
        return this.partId;
    }

    public final void setPartId(final String partId) {
        this.partId = partId;
    }

    public final String getPartVersion() {
        return this.partVersion;
    }

    public final void setPartVersion(final String partVersion) {
        this.partVersion = partVersion;
    }

    public final short getYear() {
        return this.year;
    }

    public final void setYear(final short year) {
        this.year = year;
    }

    public final int hashCode() {
        return (this.partId + '|' + this.partVersion + '|' + this.year).hashCode();
    }

    public final boolean equals(final Object other) {
        if (other instanceof ManufacturedAmountPk) {
            final ManufacturedAmountPk that = (ManufacturedAmountPk) other;
            return this.partId.equals(that.partId) && this.partVersion.equals(that.partVersion) && this.year == that.year;
        }
        return false;
    }

    @Override
    public final String toString() {
        return String.format("%s(partId='%s', partVersion='%s', year='%d')", super.toString(), this.partId, this.partVersion, this.year);
    }

}
