/*
 * Copyright (C) 2004-2010 QUIPSY QUALITY GmbH & Co. KG
 */

package entities;

import static javax.persistence.TemporalType.TIMESTAMP;
import static javax.xml.bind.annotation.XmlAccessType.NONE;

import java.util.Date;
import java.util.UUID;

import javax.persistence.Cacheable;
import javax.persistence.Column;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.Transient;
import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlID;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * Implementation class of the Part entity bean.
 * 
 * @author Markus KARG (karg@quipsy.de)
 * @author Thomas KIRSCHNER
 * @author Tobias ROTTNER (t.rottner@quipsy.de)
 * @author Ralf HAMBERGER (hamberger@quipsy.de)
 */
@XmlRootElement
@XmlAccessorType(NONE)
@Cacheable(false)
@Entity
@Table(name = "t_tl")
public final class Part {

    @SuppressWarnings("unused")
    @XmlID
    @XmlAttribute(name = "id")
    @Transient
    private String uuid = UUID.randomUUID().toString();

    /**
     * Used for separation of the single parts of the unique name.
     */
    private final static String SEPARATOR = " / ";

    @EmbeddedId
    private PartPrimaryKey pk;

    public PartPrimaryKey getPrimaryKey() {
        return this.pk;
    }

    public void setPrimaryKey(final PartPrimaryKey pk) {
        this.pk = pk;
    }

    @XmlAttribute
    public final String getName() {
        return this.pk.getId() + Part.SEPARATOR + this.pk.getVersion();
    }

    // For JAXB unmarshalling only use
    @SuppressWarnings("unused")
    private final void setName(final String name) {
        final String[] tokens = name.split(Part.SEPARATOR);
        this.pk.setId(tokens[0]);
        this.pk.setVersion(tokens[1]);
    }

    @XmlAttribute(name = "ident")
    public final String getId() {
        return this.pk.getId();
    }

    @XmlAttribute
    public final String getVersion() {
        return this.pk.getVersion();
    }

    @XmlAttribute
    @Column(name = "bezeichnung")
    private String designation;

    public final String getDesignation() {
        return this.designation;
    }

    public final void setDesignation(final String designation) {
        this.designation = designation;
    }

    @XmlAttribute
    @Column(name = "werkstoff")
    private String material;

    public final String getMaterialId() {
        return this.material;
    }

    public final void setMaterialId(String materialId) {
        this.material = materialId;
    }

    @XmlAttribute
    @Column(name = "zeichnungsnr")
    private String drawingNumber;

    public final String getDrawingNumber() {
        return this.drawingNumber;
    }

    public final void setDrawingNumber(String drawingNumber) {
        this.drawingNumber = drawingNumber;
    }

    @XmlAttribute
    @Column(name = "zeichnungsindex")
    private String drawingIndex;

    public final String getDrawingIndex() {
        return this.drawingIndex;
    }

    public final void setDrawingIndex(String drawingIndex) {
        this.drawingIndex = drawingIndex;
    }

    @XmlAttribute
    @Column(name = "infofeld_1")
    private String info1;

    public final String getInfo1() {
        return this.info1;
    }

    public final void setInfo1(String info1) {
        this.info1 = info1;
    }

    @XmlAttribute
    @Column(name = "infofeld_2")
    private String info2;

    public final String getInfo2() {
        return this.info2;
    }

    public final void setInfo2(String info2) {
        this.info2 = info2;
    }

    @XmlAttribute
    @Column(name = "infofeld_3")
    private String info3;

    public final String getInfo3() {
        return this.info3;
    }

    public final void setInfo3(String info3) {
        this.info3 = info3;
    }

    @XmlAttribute
    @Column(name = "infofeld_4")
    private String info4;

    public final String getInfo4() {
        return this.info4;
    }

    public final void setInfo4(String info4) {
        this.info4 = info4;
    }

    @XmlAttribute
    @Column(name = "infofeld_5")
    private String info5;

    public final String getInfo5() {
        return this.info5;
    }

    public final void setInfo5(String info5) {
        this.info5 = info5;
    }

    @XmlAttribute
    @Column(name = "infofeld_6")
    private String info6;

    public final String getInfo6() {
        return this.info6;
    }

    public final void setInfo6(String info6) {
        this.info6 = info6;
    }

    @XmlAttribute
    @Column(name = "infofeld_7")
    private String info7;

    public final String getInfo7() {
        return this.info7;
    }

    public final void setInfo7(String info7) {
        this.info7 = info7;
    }

    @XmlAttribute
    @Column(name = "infofeld_8")
    private String info8;

    public final String getInfo8() {
        return this.info8;
    }

    public final void setInfo8(String info8) {
        this.info8 = info8;
    }

    @XmlAttribute
    @Column(name = "infofeld_9")
    private String info9;

    public final String getInfo9() {
        return this.info9;
    }

    public final void setInfo9(String info9) {
        this.info9 = info9;
    }

    @XmlAttribute
    @Column(name = "infofeld_10")
    private String info10;

    public final String getInfo10() {
        return this.info10;
    }

    public final void setInfo10(String info10) {
        this.info10 = info10;
    }

    @XmlAttribute
    @Column(name = "notiz")
    private String note;

    public final String getNote() {
        return this.note;
    }

    public final void setNote(String note) {
        this.note = note;
    }

    @XmlAttribute
    @Column(name = "wert_pro_stueck")
    private Integer value;

    public final Integer getValue() {
        return this.value;
    }

    public final void setValue(Integer value) {
        this.value = value;
    }

    @XmlAttribute
    @Column(name = "stueckgut")
    private Integer pieceGoods;

    public final Integer getPieceGoods() {
        return this.pieceGoods;
    }

    public final void setPieceGoods(Integer pieceGoods) {
        this.pieceGoods = pieceGoods;
    }

    @XmlAttribute
    @Column(name = "angelegt_am")
    @Temporal(TIMESTAMP)
    private Date creationDate;

    public final Date getCreationDate() {
        return this.creationDate;
    }

    public final void setCreationDate(Date creationDate) {
        this.creationDate = creationDate;
    }

    @XmlAttribute
    @Column(name = "geaendert_am")
    @Temporal(TIMESTAMP)
    private Date modificationDate;

    public final Date getModificationDate() {
        return this.modificationDate;
    }

    public final void setModificationDate(Date modificationDate) {
        this.modificationDate = modificationDate;
    }

    @XmlAttribute
    @Column(name = "gesperrt")
    private boolean disabled;

    public final boolean getDisabled() {
        return this.disabled;
    }

    public final void setDisabled(boolean disabled) {
        this.disabled = disabled;
    }

    @XmlAttribute
    @Column(name = "id_produktionseinheit")
    private String productionUnitId;

    public final String getProductionUnitId() {
        return this.productionUnitId;
    }

    public final void setProductionUnitId(String productionUnitId) {
        this.productionUnitId = productionUnitId;
    }

    @XmlAttribute
    @Column(name = "ist_bemustert")
    private boolean sampled;

    public final boolean getSampled() {
        return this.sampled;
    }

    public final void setSampled(boolean sampled) {
        this.sampled = sampled;
    }

    @XmlAttribute
    @Column(name = "bilddokument")
    private String pictureDocumentId;

    public final String getPictureDocumentId() {
        return this.pictureDocumentId;
    }

    public final void setPictureDocumentId(String pictureDocumentId) {
        this.pictureDocumentId = pictureDocumentId;
    }

    @XmlAttribute
    @Column(name = "id_bild")
    private Integer pictureId;

    public final Integer getPictureId() {
        return this.pictureId;
    }

    public final void setPictureId(Integer pictureId) {
        this.pictureId = pictureId;
    }

    @Override
    public final String toString() {
        return String.format("%s(pk=%s)", super.toString(), this.pk);
    }

    @SuppressWarnings("unused")
    private final void beforeUnmarshal(final Unmarshaller unmarshaller, final Object parent) {
        this.pk = new PartPrimaryKey();
    }

}
