/*
 * Copyright (C) 2004-2008 QUIPSY QUALITY GmbH & Co. KG
 */

package entities;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Embeddable;

/**
 * Primary key of a the Part entity bean.
 * 
 * @author Markus KARG (karg@quipsy.de)
 * @author Ralf HAMBERGER (hamberger@quips.de)
 */
@SuppressWarnings("serial")
@Embeddable
public final class PartPrimaryKey implements Serializable {

    @Column(name = "ID_TEIL")
    private String id;

    @Column(name = "ID_TEILEVERSION")
    private String version;

    public PartPrimaryKey() {
        // Intentionally left blank.
    }

    public PartPrimaryKey(final String id, final String version) {
        this.id = id;
        this.version = version;
    }

    public final int hashCode() {
        return (this.id + '|' + this.version).hashCode();
    }

    public final boolean equals(final Object other) {
        if (other instanceof PartPrimaryKey) {
            final PartPrimaryKey that = (PartPrimaryKey) other;
            return this.id.equals(that.id) && this.version.equals(that.version);
        }
        return false;
    }

    public final void setId(final String id) {
        this.id = id;
    }

    public final String getId() {
        return this.id;
    }

    public final void setVersion(final String version) {
        this.version = version;
    }

    public final String getVersion() {
        return this.version;
    }

    @Override
    public final String toString() {
        return String.format("%s(id='%s', version='%s')", super.toString(), this.id, this.version);
    }

}
